@@ -3,6 +3,7 @@
 # Copyright (C) 2010 Roberto Longobardi
 #
 
+import copy
 import re
 import time
 
@@ -498,7 +499,7 @@ class TestManagerModelProvider(Component):
                         Table('testcasehistory', key = ('id', 'planid', 'time'))[
                               Column('id'),
                               Column('planid'),
-                              Column('time', type='int64'),
+                              Column('time', type=get_timestamp_db_type()),
                               Column('author'),
                               Column('status'),
                               Index(['id', 'planid', 'time'])],
@@ -512,7 +513,7 @@ class TestManagerModelProvider(Component):
                               Column('page_name'),
                               Column('name'),
                               Column('author'),
-                              Column('time', type='int64'),
+                              Column('time', type=get_timestamp_db_type()),
                               Index(['id']),
                               Index(['catid'])],
                      'has_custom': True,
@@ -582,7 +583,7 @@ class TestManagerModelProvider(Component):
         return self.SCHEMA
 
     def get_fields(self):
-        return self.FIELDS
+        return copy.deepcopy(self.FIELDS)
         
     def get_metadata(self):
         return self.METADATA
